# Pedophysics

https://sense-ugent.github.io/Pedophysics/build/html/index.html

## Description
Pedophysics, an open-source Python package designed to facilitate solutions for users who work in the field of soil assessment using near-surface geophysical electromagnetic techniques. At the core of this software is the ability to translate geophysical data into specific soil properties (and vice-versa) using pedophysical models (PM). 

## Installation

To install this package from the Python Package Index, use the following command:

```bash
pip install pedophysics 
```

Cite this code using the DOI: 10.5281/zenodo.13465701
![PyPI](https://img.shields.io/pypi/v/Pedophysics)
![Python](https://img.shields.io/pypi/pyversions/Pedophysics)
[![Docs](https://img.shields.io/badge/docs-online-blue)](https://sense-ugent.github.io/Pedophysics/)
[![License](https://img.shields.io/github/license/SENSE-UGent/Pedophysics)](LICENSE.txt)